%
% Cauchy4.m
%
function [val] = Cauchy4(M,N,h,u)
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% Cauchy4(M,N,h,u) computes a vector
% of the Cauchy transformed sinc functions
% c_j defined in Sec. 1.5.12 -- see 
% Eq. (1.5.78) -- for performing the 
% Cauchy transform over (0, infinity)
%
% Some inaccuracies may occur when 
% these results are used to obtain 
% Cauchy transforms of functions that 
% do not vanish near the origin, and 
% the user is directed to use 
% basis_harm4 for such applications.
%
% The routine calls both Sincpoints4 and
% weights4. Here u can be a vector of
% complex function values. 
%
m = M+N+1;
n = length(u);
z = Sincpoints4(M,N,h);
w = weights4(M,N,h);
%
v = pi/h*u;
%
for j=1:n
    for k=1:m
        kk = k - M - 1;
        ww = kk*pi;
        narg = v(j) - ww;
        darg = p*(u(j)-z(k));
        if abs(darg) > eps
           val(j,k) = w(k)*(exp(i*(narg) - 1)/darg;
        else
           val(j,k) = 0;
        end
    end
end
%


