%
% Cauchy5.m
%
function [val] = Cauchy5(M,N,h,u)
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% Cauchy5(M,N,h,u) computes a vector
% of the Cauchy transformed sinc functions
% c_j defined in Sec. 1.5.12 -- see 
% Eq. (1.5.78) -- for performing the 
% Cauchy transform over the real line.  
% Applciations of this routine is most 
% effective for functions that decay 
% algebraically at infinity. 
%
% The routine calls both Sincpoints5 and
% weights5. Here u can be a vector of
% complex function values. 
%
m = M+N+1;
n = length(u);
z = Sincpoints5(M,N,h);
w = weights5(M,N,h);
p = 2*pi*i;
%
v = pi/h*u;
%
for j=1:n
    for k=1:m
        kk = k - M - 1;
        ww = kk*pi;
        narg = v(j) - ww;
        darg = p*(u(j)-z(k));
        if abs(darg) > eps
           val(j,k) = w(k)*(exp(i*narg) - 1)/darg;
        else
           val(j,k) = 0;
        end
    end
end
%


