%
% `Dpoly.m'
%
function [array] = Dpoly(x)
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% This is the Sinc matrix for
% approximating the derivative of a
% function at m given distinct points 
% x = x_1, x_2, ... x_m.
% 
% We start with ordinary Lagrange polynomial 
% interpolation, 
%
% p(x) 
% = g(x) \sum_{k=1}^m {x - x_k) g'(x_k)}^{-1}f_k
% 
% where the array of m distinct finite values x = {x_k}_1^m 
% is input, and where 
%
% g(x) = (x-x_1)(x-x_2) ... (x-x_m).
% 
% We then differentiate this formula, and form an m x m 
% matrix A = [a_{j,k}],  
%
% p'(x_j) = \sum{k=-M}^N a_{j,k} f_k
%
m = length(x);
%
g_prime = basis_deriv(x);
%
for j=1:m
    for k = [1:j-1 j+1:m]
        A(j,k) = g_prime(j)/(x(j) - x(k))/g_prime(k);
    end
end
%
for j=1:m
    sum = 0;
    for l = [1:j-1 j+1:m]
        sum = sum + 1/(x(j) - x(l));
    end
    A(j,j) = sum;
end
%
array = A;
