%
% `Dpoly2_1.m'
%
function [array] = Dpoly2_1(a,b,M,N,h)
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% This is the Sinc matrix for
% approximating the derivative of a
% function on a finite interval (a,b). 
%
% See Sec. 1.7.
% 
% We start with ordinary Lagrange polynomial 
% interpolation, 
%
% p(x) 
% = g(x) sum_{k=-M}^N {x - x_k) g'(x_k)}^{-1}f(x_k)
% 
% where x_k are the m = M+N+1 Sincpoints of (a,b), 
% and where 
%
%     g(x) = (x - x_1)(x - x_2) ... (x - x_m) 
%
% We differentiate this formula with respect to x, 
% and then form an m x m matrix A = [a_{j,k}], so 
% that 
%
% p'(x_j) = sum{k=-M}^N a_{j,k} f(x_k)
%
m = M+N+1;
w2 = weights2(0,1,M,N,h);
z2 = Sincpoints2(0,1,M,N,h);
w = weights2(a,b,M,N,h);
z = Sincpoints2(a,b,M,N,h);
%
B = zeros(m);
%
% The next loop computes 
% a_{j,j} = g"(x_j)/(2 g'(x_j))
% See (1.7.6).
%
bb = g2_over_two_g1(M,N,h);
%
for j=1:m
    B(j,j) = bb(j)*w2(j)/w(j);
end
%
% Next, is a vector of values g'(z_j)
%
g2d = basis_deriv_g(M,N,h);
%
for j=1:m
    rho = h*z2(j)^2/w2(j); 
    phip2 = phi2_2(a,b,z(j));
    B(j,j) = B(j,j) + phip2/2*w(j)/h - (rho-1)/(rho+1)*h/2/w(j);
end
%
for j=1:m
    for k = [1:j-1 j+1:m] 
        B(j,k) = w2(j)/w2(k)*w(k)/w(j)*g2d(j)/g2d(k)/(z(j)-z(k));
     end
end
%
array = B;
