%
% `Dpoly4_1.m'
%
function [array] = Dpoly4_1(M,N,h)
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% See Sec. 1.7.
%
% This is the Sinc matrix for
% approximating the derivative of a function 
% F on R_+ = (0, infty), using given 
% values F(t_k) of F at the Sinc points t_k 
% of the map #4, of Sec. 1.5.3, for the 
% interval R_+.
% 
% We start with ordinary Lagrange polynomial 
% interpolation, 
%
% P(t) = p(x) ; x = rho/(1+rho)
%
% where rho = exp(phi4(t)) = sinh(t).
%
% Here p(x) takes the Lagrange polynomial form  
%
% (*) P(t) = p(x) 
% = g(x) sum_{k=-M}^N {x - x_k) g'(x_k)}^{-1} f(x_k)
%
% = G(t) sum_{k=-M}^N {t - t_k) G'(t_k)}^{-1} F(t_k)
% 
% where x_k are the m = M+N+1 Sinc points of (0,1),
% where t_k are the corresponding m Sinc points on
% R_+, and where  
%
%     g(x) = (x - x_1)(x - x_2) ... (x - x_m)
%
% We then differentiate the formula (*) with 
% respect to t and so form an m x m  matrix 
% B = [b_{j,k}], so that 
%
% P'(t_j) = sum{k=-M}^N b_{j,k} F(t_k)
%
% The following program enables us to get the b_{jk}
%
m = M+N+1;
w2 = weights2(0,1,M,N,h);
z2 = Sincpoints2(0,1,M,N,h);
w = weights4(M,N,h);
z = Sincpoints4(M,N,h);
%
B = zeros(m);
%
% The next loop computes part of G"(t_j)/(2 G'(t_j)) 
% first computing g"(x_j)/(2 g'(x_j))
% See Dpoly.m
%
bb = g2_over_two_g1(M,N,h);
for j=1:m
    B(j,j) = bb(j)*w2(j)/w(j);
end
%
for j=1:m
    rho = h*z2(j)^2/w2(j); 
    phip2 = phi4_2(z(j));
    B(j,j) = B(j,j) + phip2/2*w(j)/h - (rho-1)/(rho+1)*h/2/w(j);
end
%
% Next, is a vector of values g'(z_j)
%
g2d = basis_deriv_g(M,N,h);
%
for j=1:m
    for k = [1:j-1 j+1:m] 
        B(j,k) = w2(j)/w2(k)*w(k)/w(j)*g2d(j)/g2d(k)/(z(j)-z(k));
     end
end
%
array = B;

