%
% 'Hilb_hunter.m'
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
function [val] = Hilb_hunter(a,b,M,N,h)
%
% Hilb2(a,b,M,N,h) computes the Hilbert 
% matrix for the interval (a,b), based, 
% on Hunter's procedure, which was so 
% effective for polynomials. 
% The routine calls both Sincpoints2 and 
% weights2.  
% 
m = M+N+1;
z = Sincpoints2(a,b,M,N,h);
w = weights2(a,b,M,N,h);
II = b-a;
ll = z(m) - z(1);
%
% First compute the off diagonal part 
%
H = zeros(m);
del = zeros(m);
ww = zeros(m);
vv = zeros(m);
ons = ones(m,1);
%
for j=1:m
    for k=[1:j-1 j+1:m]
        ww(j,k) = w(k)/(z(k)-z(j));
        del(j,k) = (-1)^(j-k)/(j-k);
        vv(j,k) = ww(j,k) + del(j,k);
    end
vv(j,1) = 0;
vv(j,m) = 0;
end
%
W = ww*ons;
V0 = vv*ons;
V1 = vv*z.';
%
for j=1:m
    H(j,1) = (-II - z(m)*V0(j) + V1(j))/ll;
    H(j,1) = H(j,1) + W(j)*(z(m) - z(j))/ll;
    H(j,m) = (II - V1(j)+z(1)*V0(j))/ll;
    H(j,m) = H(j,m) + W(j)*(z(j) - z(1))/ll;
    H(j,j) = H(j,j)+(M+1-j)*h;
end
%
for j=1:m
    for k=2:m-1
        H(j,k) = H(j,k) + vv(j,k);
    end
    H(j,j) = H(j,j) + W(j);
end
%
val = (1/pi)*H;
%

       
    
