%
% 'Hilbert_t2.m'
%
function [val] = Hilbert_t2(a,b,M,N,h,u)
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% Hilbert_t2(a,b,M,N,h,u) computes a vector 
% of the Hilbert transformed sinc functions 
% t_j defined in Sec. 1.4 see Eq. (1.3.77)). 
% These definitions were computed via FORTRAN 
% in [SSc] to compute conformal maps.  
%  
% The routine calls both Sincpoints2 and 
% weights2.  Here u can be a vector of 
% function values.
% 
m = M+N+1;
n = length(u);
z = Sincpoints2(a,b,M,N,h);
w = weights2(a,b,M,N,h);
%
for j=1:n
    U(j) = phi2(u(j)); 
end
%
v = pi/h*U; 
%
% First compute the n x m `t' matrix
%
for j=1:n
    for k=1:m
        kk = k - M - 1;
        ww = kk*pi;
        narg = v(j) - ww;
        darg = pi*(u(j)-z(k));
        if abs(darg) > eps
           val(j,k) = w(k)*(cos(narg) - 1)/darg;
        else
           val(j,k) = 0;
        end
    end
end
%
% Next, compute the left end Hilbert basis:
%
for j=1:n
    Lg = log((b - u(j))/(u(j) - a));
    val1(j) = ((b - u(j))/(b-a)*Lg - 1)/pi;
    for k=2:m;
        val1(j) = val1(j) - (b-z(k))/(b-a)*val(j,k);
    end;
%
% Finally, compute the right end Hilbert basis --
%
    valm(j) = ((u(j) - a)/(b-a)*Lg + 1)/pi;
    for k=1:m-1;
        valm(j) = valm(j) - (z(k) - a)/(b - a)*val(j,k);
    end;
%
    val(j,1) = val1(j);
    val(j,m) = valm(j);
end
%


       
    
