%
% `Int_both6.m'
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
function [W1,W2,W3] = Int_both6(M,N,h)
%
% This routine sets up 3 matrices re the 
% TWO indefinite integration matrices Int6_p 
% and Int6_m for indefinite integration over
% the real line, R.  We have
%
% A =  (I^{-1}) D(h/phi') = X S X^{-1}
% B =  (I^{-1})^T D(h/phi') = Y S Y^{-1}
%
% this routine returns X, Y, and S. 
% 
% Of course, D(h/phi_6') = diag(weights6)
%
% we have 
%
%     A = X S X^{-1}
%
%     B = Y S Y^{-1}
%
% The routine returns X, Y, and S.
%
m = M+N+1;
w = weights6(M,N,h);
for j=1:m
   t = sqrt(w(j));
   d(j) = t;
   di(j) = 1/t;
end
%
D = diag(d);
Di = diag(di);
%
A = D*Im(m)*D;
[Z,W3] = eig(A);
%
W1 = Di*Z;
Zi = inv(Z);
W2 = Di*Zi.';
%
