%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
function [array] = Lap_inv(X,G,m)
%
% This is generates a vector of values 
% which approximates the inverse of the 
% Laplace transform at the Sinc points
% of an interval, Gamma, according to 
% the procedure of Sec. 1.4.10.  Before 
% entry, the user must decide on an 
% interval on which he/she wants to 
% recover  f, and then select an 
% indefinite  integration matrix --- call 
% it A --for the interval Gamma.
% The matrix can be determined 
% according to the procedure of Sec. 1.4.8. 
% Once A is determined, we factor it via 
% use of the Matlab command 
% [X S] = diag(A), we form a vector 
% s = diag(S), and we set up a diagonal 
% matrix G with j th diagonal element
% g(1/s(j))/s(j), where g denotes the 
% standard Laplace transform of f.
% The matrices X and G, and the size m of 
% these matrices are required upon entry 
% into this routine. 
%
% See the program example `ex_lapinv.m'
% and the discussion in Sec. 2.6 of this 
% manual.

vec = ones(m,1);
array = X*G*inv(X)*vec;
%
