%
function [val] = basis_harm(u,M,N,h)
%
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% This routine is used for analytic 
% continuation of boundary data to the 
% interior of a region.
%
% It computes a vector 
% of harmonic sinc basis functions 
% val_j -- see Sec. 4.1.3 of 
% Sinc-Pack 
% u = phi(x) was evaluated 
% before this routine is called.  
% 
% The user is cautioned to 
% exercise care to properly 
% evaluate u before entering this 
% routine, especially when 
% computing solutions to Laplace's
% equation for cases of re-entrant 
% corners.
%
  m = M+N+1;
  uI = imag(u);
  uR = real(u);
  v = pi/h*u;
for k=1:m
kk = k-M-1;
w = kk*pi;
harg = v - w;
    if abs(harg) > eps;
       val(k) = imag((exp(i*harg)-1)/harg);
    else;
       val(k) = 1;
    end;
end;
%
% Next, compute the left end basis:
%
rho = exp(u);
rhoR = real(1/(1+rho));
rhoI = imag(1/(1+rho));
v1 = (1-uI/pi)*rhoR - uR/pi*rhoI;
for k=2:m;
    kk = k - M - 1;
    v1 = v1 - (1/(1+exp(kk*h)))*val(k);
end;
%
% Finally, compute the right end basis --
%
rhoR = real(rho/(1+rho));
rhoI = imag(rho/(1+rho));
vm = (1-uI/pi)*rhoR - uR/pi*rhoI;
for k=1:m-1;
    kk = k - M - 1;
    vm = vm - (exp(kk*h)/(1+exp(kk*h)))*val(k);
end;
% 
%
val(1) = v1;
val(m) = vm;
%
