%
% basis_poly6.m
%
function [val] = basis_poly6(x,M,N,h)
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% See the theoretical discussion in 
% Sec. 1.5.16.
%
% The program returns a vector of m  basis 
% function b_j(x) for "polynomial" 
% interpolation on the real line 
% R = (- infty, infty) via the formula
%
% p(x) = sum_{j=-M}^N b_j(x) p(c_j)
% 
% which is exact whenever p(x) is any 
% polynomial of degre < m = M+N+1 in the 
% varible rho(x)/(1 + rho(x)), where 
% rho(x) = exp(phi6(x)). Here the c_j are 
% the Sinc points on R and 
% phi(x) is the map phi of the 
% transformation  #6 of Sec. 1.5.3.
%
rho = exp(phi6(x));
t = rho/(1+rho);
val = basis_poly2(0,1,t,M,N,h);
