%
% biharm_conv.m
%
function [array] = biharm_conv(m,X,Y,G,Gx,Gy,fr)
%
% This routine computes the integral (2.4.101), 
% with G, G_x (and similarly, G_y) as in 
% (2.4.102).  We use the same notations for 
% m, f = fr, X, Y and G, Gx, and Gy as in  
%  biharm.m
%
% U, UX = U_x, and UY = U_y are returned 
% based on using G, G_x and G_y resp.
%
% Note that the Green's function given in 
% (2.4.102) is even in x, its first derivative 
% with respect to x or y is odd, and that 
% is the reason for the signs a and b in 
% the routines below.  Recall the definition 
% of p and q in Section 1.5.9.
%
U = zeros(m);
UX = zeros(m);
UY = zeros(m);
for n=1:4
   if n == 1
     A=X; B=X; a = 1; b = 1;
   elseif n == 2
     A = X; B = Y; a = 1; b = -1;
   elseif n == 3
     A = Y; B = X; a = -1; b = 1;
   else 
     A = Y; B = Y; a = -1; b = -1;
   end
     U = U + real(conv2_vec(A,m,B,m,G,fr));
     UX =  UX + a*real(conv2_vec(A,m,B,m,Gx,fr));
     UY =  UY + b*real(conv2_vec(A,m,B,m,Gy,fr));   
end
%
clear A
clear B
clear X
clear Y
array = [U UX UY];
