%
% `burgers.m'
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% It computes the solution to Burgers' 
% equation over R x (0,infinity)
%
% Values:
%
a = 1/2;
Ep = 1/2;
b = 1;
c = 0;
% parameters
%
clear all
M1 = 15;
N1 = M1;
m1 = M1+N1+1;
h1 = 1/sqrt(N1);
M2 = 10;
N2 = M2;
m2 = M1+M2+1;
h2 = 0.7/sqrt(N2);
%
% Sinc points and weights
%
x = Sincpoints1(M1,N1,h1);
t = Sincpoints4(M2,N2,h2);
%
weights_x = weights1(M1,N1,h1);
weights_t = weights4(M2,N2,h2);
%
% Indefinte integraton matrices
% 
% Axp = Im(m1)*diag(weights_x);
Axp = Int1_p(M1,N1,h1);
% Axm = (Im(m1).'*diag(weights_x);
Axm = Int1_m(M1,N1,h1);
% Atp = Im(m2)*diag(weights_t);
Atp = Int4(M2,N2,h2);
%
% The eigenvalues and eigenvectors of 
% these matrices
%
[X S] = eig(Axp);
[Y S] = eig(Axm);
[Z,Sigma] = eig(Atp);
Xi = inv(X);
Yi = inv(Y);
Zi = inv(Z); 
s = diag(S);
sigma = diag(Sigma);
%
% The "Laplace transform" G1(s,t)=
% 
% int_0^{infinity} G(x,t) exp(-x/s) dx
%
% given the two d "Laplace transform" 
%
% G2(s,sigma) of G(x,t),
%
% evaluated at (s,t) = (sigma(i),t(j))
%
for k=1:m2
  ee(k) = 0;
  for l=1:m2
    ee(k) = ee(k) + Yi(k,l);
  end
end
%
%
% Two dimensional "Laplace transforms"
%
% Let 
%
% G1(s,t) = 
% int_0^{infty} exp(-x/s) G2(x,t) dx 
% 
% where 
%
% G2(x,t) 
% = (4 pi eps t)^{1/2} exp(-x^2/(4 eps t)) 
%
% and so G(s,sigma) = 
%
%  int_0^{infty} int_0^{infty} G2(x,t) 
%   (times) exp(-x/s -t/sigma) dx dt  
%   = (1/2) sigma s /(s + sqrt(eps sigma))
%
% and also 
%
%  int_0^{infty} G2_x(x,t) exp(-x/s-t/sigma)   
%  (times) dx dt 
% = (1/2) sigma^{1/2} (times) 
%   s /(eps^{1/2}(s + (eps sigma)^{1/2}))
%
for i=1:m1
   for j=1:m2
       G1(i,j) = 0;
       for k=1:m2
	   G1(i,j) = G1(i,j) + ...
           Y(j,k)*G2(s(i),sigma(k))*ee(k);
       end
   end
end
%         
% Evaluate the function u_0
%
% u0(x) =  a exp(-b(x-c)^2)
%
for j=1:m1
    xx = -N*h1 + (j-1)*h1;
    u0(j) = a*exp(-b*(xx-c)^2);
end
%xxxx
%
% Two dimensional "Laplace transforms"
%
% Let 
%
% G2(x,t) 
% = (4 pi eps t)^{1/2} exp(-x^2/(4 eps t)) 
%
% Then, 
%
%  int_0^{infty} int_0^{infty} G2(x,t) 
%   (times) exp(-x/s -t/sigma) dx dt  
%   = (1/2) sigma s /(s + sqrt(eps sigma))
%
%  int_0^{infty} G2_x(x,t) exp(-x/s-t/sigma)   
%  (times) dx dt 
% = (1/2) sigma^{1/2} (times) 
  %   s /(eps^{1/2}(s + (eps sigma)^{1/2}))
%
% Evaluate the 2d Laplace transform
%
for j=1:m1
   for k=1:m2
         G(j,k) = lap_tr_poi2(s(j),s(k));
   end
end
%
%
% Now, solve the PDE Lap U = - g
%
U = zeros(m1,m2);
for n=1:4
   if n == 1 
     A=X; B=X; 
   elseif n == 2
     A=X; B=Y;
   elseif n == 3
     A=Y; B=X;
   else
     A=Y; B=Y;
   end
   U = U + conv2_vec(A,m1,B,m2,G,g);
end
%
UU = real(U);
clear U
surf(z1,z2,UU);
pause
% print -dps2 pois_R_2.ps
W = UU(:,N1+1);
plot(z1,W)
% print -dps2 ex_sec_pois_R_2.ps
pause
surf(z1,z2,U_ex)
pause
surf(z1,z2,UU-U_ex)


