function [array] = conv2_vec(X,m1,Y,m2,F,g)
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% Here A = X*S*X^{-1}, (m1 x m1), 
% B = Y*T*Y^{-1}, (m2 x m2) are 
% integration matrices.  X,S,m1,Y,T,m2, as 
% well as F and g (both (m1 x m2)) are  
% externally defined, based on  
% Algorithm 5.5.1 of [SincTut].  Here F 
% is a matrix with entries which are the two 
% dimensioanl "Laplace transform" of the 
% Green's function.  That is, before entry
% into this routine, we would first form 
% A and B according to Sec. 4.3.8 of 
% [SincTut], then form X,Y,S and T via 
% [X S] = eig(A); [Y T] = eig(B); as well 
% as F, whose entries are functions of 
% the eigenvalues S and T. 
% Here g  is a matrix with (i,j)th 
% element gg(x_i, y_j), with x_i and y_j 
% denoting Sinc points on (a_1,b_1) 
% and (a_2,b_2) respectively. U (m1 x m2) 
% then approximates the indefinite 
% convolution 
% u(x,y) = \int_a^x \int_y^d f(x-x', y-y') 
% gg(x',y') dy' dx' (there are actually 4 
% such possible convolutions; all of these 
% are dealt with the same algorithm) at 
% the array of Sinc pints, (x_i, y_j).
Xi = inv(X);
Yi = inv(Y);
%
U = X*(F.*(Xi*g*Yi.'))*Y.';
clear Xi
clear Yi
clear X
clear Y
clear F
clear g
array = U;

