%
function [r]= conv_nl_discrete_r(x,z,wz,A,ker_r)
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% This program carries out the nonlinear convolution
% to approximate the integral r(x) of (1.5.61). 
% We assume the that we have as input the m_x x m_z x mx 
% array [ker_r(j,k,l)] with ker_r(j,k,l) = k(x_j,z_k,x_l), 
%  where the $x = [x_j]$ are Sinc points of (a,b), and the 
%  z = [z_k] are Sinc points of (0,c), with c (>=) b-a;
% these, as well as the weights wz and wz, and the 
% indefinite integration matrix A of order 
% mx for Sinc indefinite numerical integration over 
% (a,x), with x in (a,b) are assumed to be given.   
% 
% At the outset we determine the eigenvalues s_n and the 
% corresponding matrix X  of eigenvectors of A.  We then 
% approximate of K(x_j,s_n,x_l) by integration of the 
% integral (1.5.70) for every s = s_j and t = x_l using 
% Sinc quadrature.  
%
% Finally, we apply the formula on the extreme 
% right hand side of (1.5.72) to approximate p(x) 
% at the Sinc points x_j.
% 
mx = size(x);
mz = zize(z);
[X S] = eig(A);
s = diag(S);
Xi = inv(X);
%
% Laplace transform of k(x,t)
%
K = zeros(mx,mx,mx);
for j=1:mx
    for l=1:mx
        for k=1:mz
            K(j,n,l) =K(j,n,l) + wz(k)*ker_r(j,k,l)*exp(-z(k)/s(n));
        end
    end
end
%
% Approximating r(x_j)
%
for n=1:mx
    r(n) = 0;
    for k=1:mx
        w(k,n) = 0;
        for l=1:mx
            w(k,n) = w(k,n) + Xi(n,l)*K(k,n,l);
        end
        r(n) = r(n) + X(k,n)*w(k,n);
    end
end
    


for k=1:mx
    v(0) = 0;
    for l=1:mx
        v(k) = v(k) + Xi(k,l)*K(k,l);
    end
end
%
p = v*X.';





  

    
            
        
