
%
% `ex3_lap_inv.m'
%
% This program is copyrighted by SINC, LLC
% an belongs to SINC, LLC
%
% This is an example of Laplace 
% transform inversion, via 
% Sinc-Pack.  See Sec. 3.7
%
% Here we start with the given 
% Laplace transform, 
% hat(f)(s) = int_0^infty f(t) exp(-st) dt
% s/(1+s^2), and we wish to determine a 
% function f(t) (which we know in this 
% case, f(t) = cos(t)) on (0,infinity)
% which gives rise to this transform.  
% 
% In this case we have 
% G(s) = (1/s) hat(f)(1/s) = 1/(1+ s^2).
%
% A "usual" start:
%
clear all
%
M = 15;
N = 15;
m = M+N+1;
h = pi/sqrt(N);
%
% Sincpoints and indefinite 
% integration matrix for the 
% interval (0,infinity) -- See Sec. 3.7
%
z = Sincpoints4(M,N,h);
A = Int4_p(M,N,h);
E = eye(m);
% 
for j=1:m
   f_exact(j) = cos(z(j));
end
gg = ones(m,1);
%
fa = inv(E+A^2)*gg;
plot(z,f_exact,'.',z,fa,'o')
%
pause
%
figure(1)
title('Lapace Transform Inversions')
xlabel('Sinc Points')
ylabel('Inversions')
%print -dps2 Lap_inv.ps
%
% Plotting over the interval (0,2 pi):
step = 2*pi/500;
for j=1:500
    xx(j) = (j-1/2)*step;
    u = phi4(xx(j));
    v = basis(u,M,N,h);
    ff_exact(j) = f_exact*v.';
    ffa(j) = v*fa;
end
%
plot(xx,ff_exact,'-',xx,ffa,'.')
pause
plot(xx,ff_exact-ffa,'-')


