%
% `ex_lapinv.m'
%
% This program is copyrighted by SINC, LLC
% an belongs to SINC, LLC
%
% This is an example of Laplace 
% transform inversion, via 
% Sinc-Pack.  See Example 4.3.22 
% of [SincTut]. 
%
% Here we start with the given 
% Laplace transform, 
%  g(s) = 0.89486/s^1.31831
% and we wish to determine a function 
% f(t) on (0,2) which gives rise to 
% this transform.  We will also 
% compare with the exact expression, 
% int_0^infty t^{1/pi} exp(-st) dt
% = \Gamma(1 + 1/pi)/s^{1+1/pi}. 
%
% A "usual" start:
%
clear all
%
M = 15;
N = 10;
m = M+N+1;
h = pi/sqrt(N);
%
% Sincpoints and indefinite 
% integration matrix for the 
% interval (0,2) -- See Ex. 4.3.5
% of [SincTut]. 
%
z = Sincpoints2(0,2,M,N,h);
A = Int2_p(0,2,M,N,h);
[X S] = eig(A);
%
s = diag(S);
%
for j=1:m
   gg(j) = 0.89486*s(j)^1.31831/s(j);
end
G = diag(gg);
%
ffa = Lap_inv(X,G,m);
% 
for j=1:m
   fe(j) = z(j)^0.31831;
end
%
fa = real(ffa);
plot(z,fe,'.',z,fa,'o')
%
pause
%
figure(1)
title('Lapace Transform Inversions')
xlabel('Sinc Points')
ylabel('Inversions')
print -dps2 Lap_inv.ps
%


