
%===================================================
% lap_poi_sq.m
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% Solving Poisson problem via coupled SINC and BEM.  
% This is essentially the same program as lap_square.m
% except that it is not self-contained, i.e, we here
% use Sinc-Pack routines: Im.m, Sincpoints2.m, 
% weights2.m, the 2d Laplace tranform lap_tr_poi2.m 
% of the Green's function, and the two-d convolution
% routine, conv2_vec.m
%==================================================
% 
clear all
N = input('Enter number of Sinc points:   ')
NN = floor(N/2);
mm = 2*NN+1;
h = 1.5/sqrt(N);
m = 2*N+1;
Nd = N - NN;
format long e
%
Im= Im(m);
%
z = Sincpoints2(0,1,N,N,h);
zprime = z(m:-1:1);
w = weights2(0,1,N,N,h);
%
% Construction and diagonalization of matrices 
% Aa and Ba
%
A = Int2_p(0,1,N,N,h);
B = Int2_m(0,1,N,N,h);
%
[X S] = eig(A);
[Y T] = eig(B);
clear T
clear A
clear B
%
s = diag(S);
%
for j=1:m
   for k=1:m
      G(j,k) = lap_tr_poi2(s(j),s(k));
   end
end
%
% Computing Right Hand Side of PDE --- g  
% Matrix
%-------------------------------------
%
for ii = 1:m
  for j = 1:m
   g(ii,j) = -2;
  end
end

%
% Computing the Sinc Convolution of the 
% Green's Function  G  and P via use of 
% Sinc Convolution. 
% This yields a particular solution of 
% the non-homogeneous PDE .
%
U = zeros(m,m);
for n=1:4
   if n == 1
     A=X; B=X;
   elseif n == 2
     A = X; B = Y;
   elseif n == 3
     A = Y; B = X;
   else 
     A = Y;  B = Y;
   end
     U = U + conv2_vec(A,m,B,m,G,g);
end
%
UR = real(U);
clear U
% surf(z,z,UR):
% UI = imag(U);
U = UR;
clear UR
%
% We next need to compute a solution of the 
% homeogenous PDE to satisfy the boundary 
% conditions.  This is done via BIE, but in 
% the present program we are using Sinc 
% quadrature over (0,1) based on (2.1.16) to 
% set up the block matrix system, which 
% contains L^2 blocks re L arcs.  For our 
% problem here, L = 4. We set up the right 
% hand side vector for each arc, and the 
% block matrices.  We thus denote the right 
% hand side vector for arc `i' by bi 
% (i = 1,2,3,4 for our problem) and (i,j)^th 
% block matrix by Aij .
%
% Constructing right-hand side vectors
%
for ii = 1:m
    b2(ii) =  z(ii)^2 - U(ii,m);
    b4(ii) =  z(ii)^2 - U(ii,1);
  end
% 
for j=1:m
    b1(j) = z(m)^2 - U(m,j);
    b3(j) = z(1)^2 - U(1,j);
end
%
% First set up the diagonal block matrices, which are just -0.5 x I, 
% where I is the unit matrix.
%
A11 = -0.5*eye(m);
A22 = -0.5*eye(m);
A33 = -0.5*eye(m);
A44 = -0.5*eye(m);
%------------------------------------------------
%Computing A12 matrix
%------------------------------------------------
for ii = 1:m
    for j = 1:m
        num12 = - 0.5*w(j)*zprime(ii);
        den12 = pi*(zprime(j)^2 + zprime(ii)^2);
        frac12 = num12/den12;
        A12(ii,j) = frac12;
    end
end
%------------------------------------------------
%Computing A13 matrix
%------------------------------------------------
for ii = 1:m
    for j = 1:m
        num13 = - 0.5*w(j);
        den13 = pi*(1 + (z(ii)-z(j))^2);
        frac13 = num13/den13;
        A13(ii,j) = frac13;
    end
end
%------------------------------------------------
%Computing A14 matrix
%------------------------------------------------
for ii = 1:m
    for j = 1:m
        num14 = - 0.5*w(j)*z(ii);
        den14 = pi*(zprime(j)^2 + z(ii)^2);
        frac14 = num14/den14;
        A14(ii,j) = frac14;
    end
end
%------------------------------------------------
%Computing A21 matrix
%------------------------------------------------
for ii = 1:m
    for j = 1:m
        num21 = - 0.5*w(j)*zprime(ii);
        den21 = pi*(zprime(ii)^2 + zprime(j)^2);
        frac21 = num21/den21;
        A21(ii,j) = frac21;
    end
end
%------------------------------------------------
%Computing A23 matrix
%------------------------------------------------
for ii = 1:m
    for j = 1:m
        num23 = - 0.5*w(j)*z(ii);
        den23 = pi*(z(ii)^2 + zprime(j)^2);
        frac23 = num23/den23;
        A23(ii,j) = frac23;
    end
end
%------------------------------------------------
%Computing A24 matrix
%------------------------------------------------
for ii = 1:m
    for j = 1:m
        num24 = - 0.5*w(j);
        den24 = pi*((z(ii)-z(j))^2 + 1);
        frac24 = num24/den24;
        A24(ii,j) = frac24;
    end
end
%------------------------------------------------
%Computing A31 matrix
%------------------------------------------------
for ii = 1:m
    for j = 1:m
        num31 = - 0.5*w(j);
        den31 = pi*(1 + (z(ii)-z(j))^2);
        frac31 = num31/den31;
        A31(ii,j) =  frac31;
    end
end
%------------------------------------------------
%Computing A32 matrix
%------------------------------------------------
for ii = 1:m
    for j = 1:m
        num32 = - 0.5*w(j)*zprime(ii);
        den32 = pi*(z(j)^2 + zprime(ii)^2);
        frac32 = num32/den32;
        A32(ii,j) = frac32;
    end
end
%------------------------------------------------
%Computing A34 matrix
%------------------------------------------------
for ii = 1:m
    for j = 1:m
        num34 = - 0.5*w(j)*z(ii);
        den34 = pi*(z(j)^2 + z(ii)^2);
        frac34 = num34/den34;
        A34(ii,j) = frac34;
    end
end
%------------------------------------------------
%Computing A41 matrix
%------------------------------------------------
for ii = 1:m
    for j = 1:m
        num41 = - 0.5*w(j)*zprime(ii);
        den41 = pi*(zprime(ii)^2 + z(j)^2);
        frac41 = num41/den41;
        A41(ii,j) = frac41;
    end
end
%------------------------------------------------
%Computing A42 matrix
%------------------------------------------------
for ii = 1:m
    for j = 1:m
        num42 = - 0.5*w(j);
        den42 = pi*((z(ii)-z(j))^2 + 1);
        frac42 = num42/den42;
        A42(ii,j) = frac42;
    end
end
%------------------------------------------------
%Computing A43 matrix
%------------------------------------------------
for ii = 1:m
    for j = 1:m
        num43 = - 0.5*w(j)*z(ii);
        den43 = pi*(z(ii)^2 + z(j)^2);
        frac43 = num43/den43;
        A43(ii,j) = frac43;
    end
end
%
% Now use the above created matrices and vector to create the `big system'
% of equations.
%
A = [A11 A12 A13 A14; A21 A22 A23 A24; A31 A32 A33 A34;...
        A41 A42 A43 A44];
b = [b1 b2 b3 b4].';
%----------------------------------------------
%Solving linear equations
%----------------------------------------------
sol = A\b;
%----------------------------------------------
%Approximate solution
%----------------------------------------------
     new1 = sol(1:m);
     new2 = sol(m+1:m+m);
     new3 = sol(m+m+1:2*m+m);
     new4 = sol(2*m+m+1:2*m+2*m);
 %
 fac = 1.0/(2*pi);
 %
 for ii = 1:m
     for j = 1:m
         u11 = 0.0;
         u22 = 0.0;
         u33 = 0.0;
         u44 = 0.0;
         for k = 1:m
             num1 = w(k)*new1(k);
             den1 = zprime(ii)^2 + (z(j) - z(k))^2;
             u11 = u11 -(zprime(ii)*num1)/den1;
             num3 = w(k)*new3(k);
             den3 = z(ii)^2 + (z(j) - z(k))^2;
             u33 =u33 - (z(ii)*num3)/den3;
         end
         for k=1:m
             num2 = w(k)*new2(k);
             den2 = (z(ii) - z(k))^2 + zprime(j)^2;
             u22 = u22 - (zprime(j)*num2)/den2;
             num4 = w(k)*new4(k);
             den4 = (z(ii) - z(k))^2 + z(j)^2;
             u44 = u44 - (z(j)*num4)/den4;
         end
             u(ii,j) =  fac*(u11 + u22 + u33 + u44);
      end
  end
 %Approximte solution
 v = u+U;
 approx = diag(v);
%
for j=1:mm
   zz(j) = z(j+Nd);
end
%
for j=1:mm
   for k=1:mm
      vv(j,k) = v(j+Nd,k+Nd);
   end
end
     
surf(zz,zz,vv)
print -dps2 Cut_surf_lap_poi_sq.ps
%
pause
%
% Error.
%
meas = 0;
for ii=1:m
    for j=1:m
        meas = meas + w(ii)*w(j)*(z(ii)^2 - v(ii,j))^2;
    end
end
meas = sqrt(meas);
 %Exact solution and error
 %
 figure(1) 
 plot(z, approx, z, z.^2,'o')
% plot(z,z.^2)
 xlabel('Sinc points')
 ylabel('Approximate, "o" and Exact, "-"')  
 print -dps2 X-Sec_lap_poi_sq.ps

 
