%
% `navier_stokes_ic.m'
%
function [U01,U02,U03] = navier_stokes_ic(z)
%
% This program is copyrighted by SINC, LLC
% an belongs to SINC, LLC
% 
% This program evaluates each of the three 
% components of the the initial value vector
% at the set of points (z(i), z(j), z(k)) 
% for solution of the Navier-Stokes example 
% in Sec. 4.3.  We have taken here the function 
%
% u^0 = (y - z, z - x, x - y) exp( -r^2), 
% 
% which satisfies div(u^0) = 0 in R^3.
%
m = length(z);
%
for j = 1:m
    a = z(j);
    ea2 = exp(-a^2);
    for k = 1:m
        b = z(k);
        eb2 = ea2*exp(-b^2);
        for l = 1:m
            c = z(l);
            ec2 = eb2*exp(-c^2);
            U01(j,k,l) = (b-c)*ec2;
            U02(j,k,l) = (c-a)*ec2;
            U03(j,k,l) = (a-b)*ec2;
         end
     end
end
%

            

