%
% Program: `p_d_T5.m' 
%
% This program is copyrighted by SINC, LLC
% an belongs to SINC, LLC
% 
% Sinc  successive approximation solution of 
%
% F(x,t) = F_0(x) + U(x,t) - V(x,t) 
%
% over 
%
% (0,infinity) x {(0,T), (T,2T), (2T,3T), (3T,4T) and (4T,%T)} 
%
% Here, 
%
%   U(x,t) = int_0^t int_x^infinity G(x,u) b(u) "times" 
%               "times" F_x(u,tau) du dtau 
%
%   V(x,t) = int_0^t mu(tau) int_0^x F_x(v,tau) "times" 
%     "times" int_{x-v}^infinity w^{-1} a(v,w) "times" 
%      "times" F_x(w,tau) dw dv dtau
%
% The initial condition has a bad boundary layer.  G(x,y)
% is also badly behaved near (x,y) = (0,0).
%
clear all
%
format long e
%
M1 = 12;
N1 = 9;
m1 = M1 + N1 + 1;
M2 = 7;
N2 = 7;
m2 = M2 + N2 + 1;
hx = .5/sqrt(N1);
ht = 0.3/sqrt(N2);
T = 0.05;
%
% Sinc Points, Weights, and Matrices
%
x = Sincpoints3(M1,N1,hx);
% x = Sincpoints4(M1,N1,hx);
wx = weights3(M1,N1,hx);
% wx = weights4(M1,N1,hx);
%
tau = Sincpoints2(0,T,M2,N2,ht);
Axp = Int3_p(M1,N1,hx);
Axm = Int3_m(M1,N1,hx);
% Axp = Int4_p(M1,N1,hx);
% Axm = Int4_m(M1,N1,hx);
% 
% The derivative matrices
%
% The "x" derivative matrix on (0,infinity)
%
Axd = Dpoly3_1(M1,N1,hx);
% Axd = Dpoly4_1(M1,N1,hx);
%
% Indef integration wrt t over (0,T) matrix
%
Atp = Int2_p(0,T,M2,N2,ht);
%
% Now diagonalize the matrix Axp, for 
% Sinc convolution
%
[Y S] = eig(Axp);
s = diag(S);
%
% First, some definitions of functions and 
%
% some diagonal matrices.
%
for j=1:m1
% the initial F_0 
     F0(j) = 1 - exp(- x(j)/0.05);
% 
     b(j) = 1/(1+x(j)^2);
     for k=1:m1
% The next two are values of G and a 
% 
%         G(j,k) = 1/sqrt(1 + x(j)^4 + x(k)^4); 
         G(j,k) = x(j)/(x(j)^2 + x(k)^2+1);
         a(j,k) = x(k)/(x(j)^2 + x(k)^2+1);
     end
end
%
% The diagonals of full matrices
%
for j=1:m1
    for k=1:m2
%
    % The initial value of F
    %
    FF0(j,k) = F0(j);
    end
end
%
% The approximation of "mu"
%
for k=1:m2
    mu(k) = 1/(1+tau(k)^2);
end
Dmu = diag(mu);
%
% This is a row vector of the diagonal 
% entries of S
%
Yi = inv(Y);
%
% Beginning of "time-strip", ll - loop, to compute 
% the solution F on the time interval I_l = ((ll-1)T,(ll)T)
%
%
for ll=1:5
%
% A bit more initialization for I_l, I_2, I_3, I_4 & I_5
%
    for j=1:m2
% Sinc points on  I_l
        t(j) = (ll-1)*T+tau(j); 
        Dmu(j,j) = 0.2/(1+t(j)^2);
    end
%
% Start of iterative "contraction"  loop
%
    F = FF0;  % FF0 = F(x,t)|_{t=0}
    nn = 1; 
%
% The value of the "least squares" 
% convergence norm, is here set to 1
    while(nn > 0.00001)
%
% First, compute the U = U(x,t) - Part
%
% F_x denoted by Fx
%
        Fx = Axd * F;
%
% Next, G(x,u) b(u) F_x(u,tau)
%
        for j=1:m1
            for k=1:m2
                for l=1:m1
                    GbFx(k,j,l) = G(j,l) * b(l) * Fx(l,k);
                end
            end
        end
%
% P2(x,tau) = int_x^infinity G(x,u) b(u) F_x(u,tau) du
%
        P2 = zeros(m2,m1);
        for k=1:m2
             for j=1:m1
                for l=1:m1
                    P2(k,j) = P2(k,j) + GbFx(k,j,l)*Axm(j,l);
                end
            end
        end
%
        clear GbFx PP2
%
% We now get U(x,t) at Sinc pts.:
% U(x,t) = int_0^t P2(x,tau) dtau
%
        U = (Atp*P2).';
% 
        clear P2
%
%  V(x,t) is next:
%
        for k=1:m2
            for j=1:m1
                Fxx(l) = F(l,k);
                for l=1:m1
                    awFx(j,l) = a(j,l)/x(l)*Fxx(l); 
                 % awFx(v,w,tau) = a(v,w)/w*F_x(w,tau)
                end
            end
        
%
% Set ker_p(v,y,tau) = int_y^infinity awFx(v,w,tau) dw
% 
            ker_p = Axm*awFx;
            p = real(conv_nl_discrete_p(x,x,wx,Axp,ker_p));
            for l=1:m1
                p(l) = Fxx(l)*p(l);
            end
            PP(k,l) = p(l);
        end
%
% At this stage we have 
% int_0^x F_x(v,tau) int_{x-v}^infty (a(v,w)/w) F(w,tau).
%
% We next multiply this by mu(tau) and integrate the result from 
% 0 to t:
%
V = PP.'*Dmu*Atp.';
       
%
clear awFx
%

%
        UpV = real(U-V);
%        
        FF = FF0 + UpV;
%
        clear UpV
        nn0 = norm(F - FF);
        F = FF;
        vector_iter_norm = nn0
        nn = nn0;
%
% End of "contraction iteration" loop
%
    end 
%
% Printing a postscript file of the 
% surface F
%
    if(ll<2) 
        figure(1)
        surf(t,x,F)
        pause
        print -dps2 p_d_T5_1.ps
%
    elseif(ll>1) & (ll<3)
        figure(2)
        surf(t,x,F)
        pause
        print -dps2 p_d_T5_2.ps
%
    elseif(ll>2) & (ll<4)
        figure(3)
        surf(t,x,F)
        pause
        print -dps2 p_d_T5_3.ps
%
    elseif(ll>3) & (ll<5)
        figure(4)
        surf(t,x,F)
        pause
        print -dps2 p_d_T5_4.ps
%
    elseif(ll>4)
        figure(5)
        surf(t,x,F)
        pause
        print -dps2 p_d_T5_5.ps
    end
 %
 % Initialization for next I_l
 %
 for j=1:m1
        for k=1:m2
            FF0(j,k) = F(j,m2);
        end
 end
        %
        % End of "time-strip" loop
        %
        %
end
