%
% Program:  `terryinf2.m'
%
% This program is copyrighted by SINC, LLC
% an belongs to SINC, LLC
% 
% F(x,t) = F_0(x) + U(x,t) - V(x,t) 
%
%   U(x,t) = int_0^t int_x^infinity G(x,u) b(u) "times" 
%               "times" F_x(u,tau) du dtau 
%
%   V(x,t) = int_0^t mu(tau) int_0^x F_x(v,tau) "times" 
%     "times" int_{x-v}^infinity w^{-1} a(v,w) "times" 
%      "times" F_x(w,tau) dw dv dtau
%
% A solution over (0,infty) x (0,infty) is computed, 
% where the initial condition has a boundary layer.
%
clear all
%
% Initial value inputs
%
tic
M1 = 18;
N1 = 15;
m1 = M1 + N1 + 1;
M2 = 15;
N2 = 12;
m2 = M2 + N2 + 1;
ht = 0.5/sqrt(N2);
hx = 1.0/sqrt(N1);
%
format long e
%
% Sinc Points, Weights, and Matrices
%
x = Sincpoints4(M1,N1,hx);
wx = weights4(M1,N1,hx);
%
x = Sincpoints4(M1,N1,hx);
wx = weights4(M1,N1,hx);
%
t = Sincpoints3(M2,N2,ht);
wt = weights3(M2,N2,ht);
% t = Sincpoints4(M2,N2,ht);
% wt = weights4(M2,N2,ht);
%
% First, some definitions of functions and 
%
% some diagonal matrices.
%
for j=1:m1
% the initial F_0
% F0(j) = 1 - (1 + x(j)) * exp(- x(j));
F0(j) = 1 - exp(- x(j)/0.1); 
% F0(j) = 1 - (1 + x(j)^2) * exp(- x(j)^2);
b(j) = 1/(1+x(j)^2); % b(x) = 1/(1+x^2)
for k=1:m1
% The next two are values of G and a 
 G(j,k) = x(j)/(x(j)^2 + x(k)^2+1);
 a(j,k) = x(j)/(x(j)^2 + x(k)^2+1);
end
end
%
% The diagonals of full matrices
%
for j=1:m1
for k=1:m2
%
% The initial value of F
%
FF0(j,k) = F0(j);
end
end
%
% The approximation of "mu"
%
Dmu = eye(m2);
%
for k=1:m2
Dmu(k,k) = 1/(1+t(k)^2);
end
%
% The derivative matrices
%
% The "x" derivative matrix on (0,infinity)
%
% Integration over (0,x) and (x,infinity)
%
Axp = Int4_p(M1,N1,hx);
Axm = Int4_m(M1,N1,hx);
%
Axd = D44_1(M1,N1,hx);
% Axd = inv(Axp);
%
% Integration over (0,t)
%
Atp = Int3_p(M2,N2,ht);
% Atp = Int4_p(M2,N2,ht);
% Now diagonalize the matrix Axp, for 
% Sinc convolution
%
[Y S] = eig(Axp); 
s = diag(S); 
% This is a vector of the diagonal entries of S
%
% Start of iterative "contraction"  loop
%
% 
F = FF0;  % FF0 = F(x,t)|_{t=0}
nn = 1 % The value of the "least squares" 
% convergence norm, is here set to 1
while(nn > 0.0001)
%
te_F = ter_GGG(m1,m2,x,wx,t,wt,Y,s,b,G,a,FF0,F,Dmu,Axd,Axp,Axm,Atp);
F = F-te_F;
nn = norm(te_F)
end
toc
%
surf(t,x,F)
