%
% `wave2_3p1.m'
%
% This program is copyrighted by SINC, LLC
% an belongs to SINC, LLC
%
% This is the MAIN routine for computation of 
% the wave problem c^{-2} u_{tt} = nabla u
% on R^3 x (0,TT), via Sinc convolution.  
% The exact solution is 
% u(r,t) = t^(1/2)*exp(-r^2 - c*t).
%
% `wave2_3p1.m'
%
% Initializations:
%
clear all
%
c=1/2;
%
TT = 0.1;
%
p1=15;
p2=15;
p3=15;
p4=14;
pp4 = floor(2*p4/3);
%
M1 = p1;
N1 = p1;
m1 = M1+N1+1;
h1 = 1/sqrt(N1);
xx = Sincpoints1(M1,N1,h1);
A1 = Int1_p(M1,N1,h1);
B1 = Int1_m(M1,N1,h1);
[W1 R] = eig(A1);
[W2 R] = eig(B1);
rrr = diag(R);
M2 = p2;
N2 = p2;
m2 = M2+N2+1;
h2 = 1/sqrt(N2);
A2 = Int1_p(M2,N2,h2);
B2 = Int1_m(M2,N2,h2);
[X1 S] = eig(A2);
[X2 S] = eig(B2);
sss = diag(S);
yy = Sincpoints1(M2,N2,h2);
M3 = p3;
N3 = p3;
m3 = M3+N3+1;
h3 = 1/sqrt(N3);
zz = Sincpoints1(M3,N3,h3);
A3 = Int1_p(M3,N3,h3);
B3 = Int1_m(M3,N3,h3);
[Y1 T] = eig(A3);
[Y2 T] = eig(B3);
ttt = diag(T);
M4 = p4+4;
N4 = p4;
m4 = M4+N4+1;
mm4 = M4+pp4;
h4 = 0.8/sqrt(N4);
% tt = Sincpoints4(M4,N4,h4);
tt = Sincpoints2(0,TT,M4,N4,h4);
% A4 = Int4_p(M4,N4,h4);
A4 = Int2_p(0,TT,M4,N4,h4);
[D U] = eig(A4);
uuu = diag(U);
clear R
clear S
clear T
clear U
%
% Setting up the right hand side
% of c^{-2}u - nabla u = f 
% f (called ff here) and the 
% exact solution, ex.
%
for ii=1:m1
   for j=1:m2
      for k=1:m3
         x = xx(ii); y = yy(j); z = zz(k);
         r2 = x^2+y^2+z^2;
         for l=1:m4
         t = tt(l);
         ct = 1/c/t;
         th = sqrt(t);
         ee = th*exp(-r2-c*t);
         fe = (7 -ct+3/4*ct^2-4*r2);
         ff(ii,j,k,l) = fe*ee;
         ex(ii,j,k,l)= ee;
         end
      end
   end
end
%
% Setting up of the "Laplace transform"
% of the Green's function, as described 
% in Lemma 5.6.5 of [SincTut].
%
for ii=1:m1
    u=rrr(ii);
   for j=1:m2
       v = sss(j);
      for k=1:m3
         w = ttt(k);
         for l=1:m4
            t = uuu(l);
          G(ii,j,k,l) = lap_tr4_wave(u,v,w,t,c);
         end
      end
   end
end
%
% Now, solve the PDE
%
U = zeros(m1,m2,m3,m4);
%
for n=1:8
   if n == 1
    A = W1; B = X1; C = Y1;
   elseif n == 2
    A = W1; B = X1; C = Y2;
   elseif n == 3
    A = W1; B = X2; C = Y1;   
   elseif n == 4
    A = W1; B = X2; C = Y2;
   elseif n == 5
    A = W2; B = X1; C = Y1;   
    elseif n == 6
    A = W2; B = X1; C = Y2;
   elseif n == 7
    A = W2; B = X2; C = Y1;
   else 
    A = W2; B = X2; C = Y2;
   end
   U = U + conv4_vec(A,m1,B,m2,C,m3,D,m4,G,ff);
end
%
U = real(U);
%
clear ff
clear G
%
for l=1:m4
    for k=1:m3
        VR1(k,l) = U(M1+1,M2+1,k,l);
        ER1(k,l) = ex(M1+1,M2+1,k,l);
    end
    ER3(l) = U(M1+1,M2+1,M3+1,l);
    EX3(l) = ex(M1+1,M2+1,M3+1,l);
end
%
plot(tt,EX3,'o',tt,ER3,'.')
pause
for j=1:mm4
   t4t(j) = tt(j);
   E4X3(j) = EX3(j);
   E4R3(j) = ER3(j);
end
%
plot(t4t,E4X3,'o',t4t,E4R3,'.')
%
pause
%
surf(tt,zz,VR1)
pause
surf(tt,zz,ER1)
pause
ZR1 = VR1(M3+1,:);
plot(tt,ZR1);
pause
% 
% for ii=1:m1
%    for j=1:m3
%       VR2(ii,j) = U(ii,j,M3+1,M4+1);
%       ER2(ii,j) = ex(ii,j,M3+1,M4+1);
%    end
% end
%
VR2 = U(:,:,M3+1,M4+1);
ER2 = ex(:,:,M3+1,M4+1);
%
surf(yy,xx,VR2)
pause
surf(yy,xx,ER2)
pause
ZR2 = VR2(M3+1,:);
plot(yy,ZR2)
pause
%
ZR3 = VR2(:,M2+1);
plot(xx,ZR3)
%
