%
% `wave_3p1.m'
%
% This program is copyrighted by SINC, LLC
% an belongs to SINC, LLC
%
% This is the MAIN routine for computation of 
% the wave problem c^{-2} u_{tt} = nabla^2 u = f
% on R^3 x (0,\infty), via Sinc convolution.  
% The exact solution is 
%
% u(r,t) = t^(3/2)*exp(-r2 - c*t), with th = t^{1/2}.
%
% Initializations:
%
clear all
%
tic
c=1/2;
%
TT = 0.09;
%
p1=10;
p2=10;
p3=10;
p4=7;
%
M1 = p1;
N1 = p1;
m1 = M1+N1+1;
h1 = .6/sqrt(N1);
xx = Sincpoints5(M1,N1,h1);
[W1,W2,R] = Int_both5(M1,N1,h1);
rrr = diag(R);
M2 = p2;
N2 = p2;
m2 = M2+N2+1;
h2 = .6/sqrt(N2);
[X1,X2,S] = Int_both5(M2,N2,h2);
sss = diag(S);
yy = Sincpoints5(M2,N2,h2);
M3 = p3;
N3 = p3;
m3 = M3+N3+1;
h3 = .6/sqrt(N3);
zz = Sincpoints5(M3,N3,h3);
[Y1,Y2,T] = Int_both5(M3,N3,h3);
ttt = diag(T);
M4 = p4;
N4 = p4;
m4 = M4+N4+1;
h4 = 3.5/sqrt(N4);
tt = Sincpoints2(0,TT,M4,N4,h4);
A4 = Int2_p(0,TT,M4,N4,h4);
[D U] = eig(A4);
uuu = diag(U);
clear R
clear S
clear T
clear U
%
% Setting up the right hand side
% of c^{-2}u_t - nabla^2 u = f 
% f (called ff here) and the 
% exact solution, ex.
%
for ii=1:m1
   for j=1:m2
      for k=1:m3
         x = xx(ii); y = yy(j); z = zz(k);
         r2 = x^2+y^2+z^2;
         f1 = exp(-r2);
         for l=1:m4
         t = tt(l);
         ct = 1/c/t;
         th = sqrt(t);
         ee = th^3*exp(-r2-c*t);
         fe = (7-3*ct+3/4*ct^2-4*r2);
         ff(ii,j,k,l) = fe*ee;
         ex(ii,j,k,l)= ee;
         end
      end
   end
end
%
% Setting up of the "Laplace transform"
% of the Green's function, as described 
% in Lemma 2.4.6 of this tutorial.
%
for ii=1:m1
    u=rrr(ii);
   for j=1:m2
       v = sss(j);
      for k=1:m3
         w = ttt(k);
         for l=1:m4
            t = uuu(l);
          G(ii,j,k,l) = lap_tr_wave4(u,v,w,t,c);
         end
      end
   end
end
%
% Now, solve the PDE
%
U = zeros(m1,m2,m3,m4);
%
for n=1:8
   if n == 1
    A = W1; B = X1; C = Y1;
   elseif n == 2
    A = W1; B = X1; C = Y2;
   elseif n == 3
    A = W1; B = X2; C = Y1;   
   elseif n == 4
    A = W1; B = X2; C = Y2;
   elseif n == 5
    A = W2; B = X1; C = Y1;   
    elseif n == 6
    A = W2; B = X1; C = Y2;
   elseif n == 7
    A = W2; B = X2; C = Y1;
   else 
    A = W2; B = X2; C = Y2;
   end
   U = U + conv4_vec(A,m1,B,m2,C,m3,D,m4,G,ff);
end
%
U = real(U);
%
clear ff
clear G
%
for l=1:m4
    for k=1:m3
        VR1(k,l) = U(M1+1,M2+1,k,l);
        ER1(k,l) = ex(M1+1,M2+1,k,l);
    end
    ER3(l) = U(M1+1,M2+1,M3+1,l);
    EX3(l) = ex(M1+1,M2+1,M3+1,l);
end
%
toc
figure(1)
plot(tt,EX3,'o',tt,ER3,'-')
xlabel('Time')
ylabel('Approximate, "-" and Exact "o" u(0,0,0,t)')
print -dps2 Exact.vs.Appr_3d_wave_t_plot.ps
pause
%
figure(2) 
surf(tt,zz,VR1)
xlabel('Time')
ylabel('z')
zlabel('Approximate u(0,0,z,t)')
print -dps2 Appr_3d_wave_zt_plot.ps
pause
figure(3)
surf(tt,zz,VR1-ER1)
xlabel('Time')
ylabel('z')
zlabel('Approx - Exact u(0,0,z,t)')
print -dps2 Approx_Exact_3d_wave_zt_plot.ps
pause
%
for ii=1:m1
   for j=1:m3
      VR2(ii,j) = U(ii,j,M3+1,M4+1);
      ER2(ii,j) = ex(ii,j,M3+1,M4+1);
   end
end
%
figure(4)
surf(yy,xx,VR2)
xlabel('x')
ylabel('y')
zlabel('Approximate u(x,y,0,0)')
print -dps2 Appr_3d_wave_xy_plot.ps
pause
figure(5)
surf(yy,xx,VR2-ER2)
xlabel('x')
ylabel('y')
zlabel('Approx - Exact u(x,y,0,0)')
print -dps2 Approx_Exact_3d_wave_xy_plot.ps


