
%
% `wavelet_basis_even_half.m'
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
function [w] = wavelet_basis_even_half(P,N,x)
%
% wavelet_basis_even_half computes a 
% vector of M = 2*N functions w_j(x)
% for evaluating the periodic of 
% period P  function f on (0,P) via the 
% formula 
%
% S(x) = sum_{j=1}^M  f((j-1/2)h) w_j(x)
%
% with h = P/M
%
% w_j(x) = U_j/V_j 
%
% with 
%
% U_j = sin{pi/h * (x-jh+h/2)} * cos(pi/P*(x-j*h+h/2)/2)
%
% V_j = M sin{pi/P*(x-jh+h/2)}
%
% See Corollary 1.4.4(i).
%
M = 2*N;
h = P/M;
%
for j=1:M
    v = (j-1/2)*h;
    targ = pi/P*(x - v);
    if abs(targ) > eps;
       w(j) = sin(M*targ)*cos(targ)/(M*sin(targ));
    else
       w(j) = 1;
    end
end
%

