%
% `wavelet_basis_even_int.m'
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
function [w] = wavelet_basis_even_int(P,N,x)
%
% wavelet_basis_even_int computes a 
% vector of M+1 = 2*N+2 functions w_j(x), 
% for evaluating the periodic of
% period P  function f on [0,P] via the
% formula
%
% S(x) = \sum_{j=1}^(M+1) d_j f((j-1)h) w_j(x)
%
% where, with h = P/M, with d_1 = d_{M+1} = 1/2,
%
% and with   
%
% w_j(x) = U_j/V_j
%
% where
%
% U_j = sin{(pi/h* (x-(j-1)h)} * cos(pi/P*(x-j*h-h))
%
% V_j = M sin{pi/P*(x-jh-h)}
%
% See Corollary 1.4.3(i).
%
M = 2*N;
Mp1 = M+1;
h = P/M;
%
for j=1:Mp1
    v = (j-1)*h;
    targ = pi/P*(x - v);
    if abs(targ) > eps;
       w(j) = sin(M*targ)*cos(targ)/(M*sin(targ));
    else
       w(j) = 1;
    end
end
%
% half end values
%
w(1) = w(1)/2;
w(Mp1) = w(Mp1)/2;
%
