%
% `wavelet_basis_odd_half.m'
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
function [w] = wavelet_basis_odd_half(P,N,x)
%
% wavelet_basis_odd_half computes a 
% vector of M = 2*N+1 functions w_j(x) 
% for evaluating the periodic 
% of period P  approximation 
%
% S(x) = \sum_{j=1}^M f((j-1/2)h) w_j(x)
% 
% over [0,P], where, with h = P/M,
%
% w_j(x) = U_j/V_j
%
% with 
%
% U_j = sin{pi/h * (x-jh+h/2)} 
%
% V_j = M*sin{(x-jh+h/2)/2}
%
% See Corollary 1.4.6(i).
%
M = 2*N+1;
h = P/M;
%
for j=1:M
    v = (j-1/2)*h;
    targ = pi/P*(x - v);
    if abs(targ) > eps;
       w(j) = sin(M*targ)/(M*sin(targ));
    else
       w(j) = 1;
    end
end
%

