%
% `wavelet_main_odd_half.m'
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% This is a main program for testing out 
% some periodic basis functions defined 
% in the routine wavelet_basis_odd_half.m
% 
% We interpolate here the function exp(x)
% on [0,1], which is discontinuous at the
% integers, when considered as a periodic
% function of period 1 on the real line.
%
clear all
%
N = 10;
M = 2*N+1;
P = 1;
h = P/M;
%
for j=1:M
    t = (j-1/2)*h;
    z(j) = t; 
    f1(j) = exp(t);
    f2(j) = 1/sqrt(1 - 0.5*cos(2*pi*t));
end
%
g1_exact = f1.';
g2_exact = f2.';
%
step = P/300;
for j = 1:300
    y = (j-0.5)*step;
    x(j) = y;
    vec = wavelet_basis_odd_half(P,N,y);
    g1_approx(j) = vec*g1_exact;
    g2_approx(j) = vec*g2_exact; 
 end
%
figure(1)
plot(z,g1_exact,'o',x,g1_approx,'-');
pause
title('Wavelet Interp. of $e^x$ at 21 Half Interval Values')
pause
print -dps2 wavelet_basis_odd_half_exp.ps
pause
figure(2)
plot(z,g2_exact,'o',x,g2_approx,'-');
pause
title('Wavelet Interp. of $(1-(1/2)cos(2\pi x))^{-1/2}$ at 21 Half Interval Values')
pause
print -dps2 wavelet_basis_odd_half_cos_root.ps
