%
% `wavelet_odd_half_Int_p.m'
%
function [A] = wavelet_odd_half_Int_p(N,a,b)
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% wavelet_odd_half_Int_p(N,a,b) computes the 
% matrix A = [A_{jk}] of order M = 2N+1, where,
% with P = b - a, and for k in [1,M], 
% A_{jk} = E_o(N,P,x_j-x_k) - E_o(N,P,a - x_k)
% and with x_k = a + (k-1/2)P/(2N+1), k=1, ... 2N+1.
% See (1.4.105).
%
% NOTES:
%
% 1.  A_{jk} is the coeff, of f((k-1/2)h) when 
% integrating the right hand side of (1.4.22) 
% from a to x_j = a + (j-1/2)h.
% 
% 2. Setting f_j = f(a + (j-1/2)h), j = 1, 2, ... 2N+1, 
% f = (f_1, ..., f_{2N+1})^T, and F = Af,
% we can again use the formula on the right
% hand side of (1.4.22) to get an approximation of 
% F(x) = int_a^x f_h(t) dt for any x in [a, b].  
% The program `wavelet_basis_odd_half.m' may be used 
% for this purpose, to yield an interpolation that is 
% exact at the interpolation points x_j.
%
P = b - a;
M = 2*N+1;
h = P/M;
for k=1:M
    x(k) = a + (k-1/2)*h;
end
%
for k=1:M
    bb  = waveletint_o(N,P,a - x(k));
    for j=1:M
        aa = waveletint_o(N,P,x(j)-x(k));
        A(j,k) = aa -bb;
    end
end
