%
%  `wavelet_odd_int_Int_both.m'
%
function W = wavelet_odd_int_Int_both(N,a,b)
% 
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% This routine sets up 4 matrices re the
% TWO indefinite integration matrices A 
% computed in  `wavelet_odd_int_Int_p.m' 
% and B, computed in `wavelet_odd_int_Int_m.m'
%
% A =  X S X^{-1}
% B =  Y T Y^{-1}
%
% This routine then returns 
% a long row vector, [x,s,y,t],
% where, with m = 2*N+2; m1 = m^2;
%
%  x = reshape(X,1,m1)
%  s = diag(S)
%  y = reshape(Y,1,m1)
%  t = duag(T)
%
%  Then, with m = 2*N+2, X,s,Y,t may be 
% recovered via use of the statements 
% m1 = m^2; m2 = m1 + m; 
% m3 = m2 + m1; m4 = m3+m;
%
% X = reshape(W(1:m1),m,m);
% s = W(m1+1:m2);
% Y = reshape(W(m2+1:m3),m,m);
% t = W(m3+1:m4);
%
A = wavelet_odd_int_Int_p(N,a,b);
B = wavelet_odd_int_Int_m(N,a,b);
%
m = 2*N+2;
m1 = m^2;
[X S] = eig(A);
[Y T] = eig(B);
s = diag(S);
t = diag(T);
x = reshape(X,1,m1);
y = reshape(Y,1,m1);
%
W = [x s y t];


