%
% "wavelet_ode_ivp_nl1.m"
%
% This program is copyrighted by SINC, LLC
% and belongs to SINC, LLC
%
% Here we solve the following
%  problem:
% 
% y' = f(x,y); y(0) = tan(0.2)
%
% with f(x,y) = "ode_f1"(x,y) = 1+y^2. 
% 
% The problem is solved on (0,0.6), 
% subject to y(0) = tan(0.2), using 
% Sinc collocation and Sinc-wavelet  
% indefinite integration combined 
% with Picard iteration, over the 
% interval (0,0.6).  
%
% In the program, the 
% ode_f1_exact(x) = tan(x+0.2), which is 
% the exact solution.  
%
clear all
P = 0.6;
N = 20;
M = 2*N;
h = P/M;
y0 = tan(0.2);
for j=1:M+1;
    x(j) = (j-1)*h;
    y00(j) = y0;
end
A = waveletintmat_e_int(N,P);
Er = 5;
%
yy = y00.';
y = y00.';
% 
while(Er > .00001)
     for k=1:M+1
        W(k) =  ode_f1(x(k),y(k));
     end   
%
     y = y00.' + A*W.';
     Err = norm(y - yy);
     yy = y;
     Er = Err
end
%
% Plots at j*P/300
%
step = P/300;
for j=1:301
     t = (j-1)*step;
    ex(j) = ode_f1_exact(t);
    xx(j) = t;
    w = wavelet_basis_even_int(P,N,t);
    Y(j) = w*yy;
end
%
figure(1)
plot(xx,ex,'-',xx,Y,'o')
%
pause
%
title('Wavelet-Picard Solution of y^\prime = 1+y^2')
pause
print -dps2 wavelet_nl_ode.ps
%
figure(2)
plot(xx,Y-ex)
pause
title('Wavelet-Picard Error of y^\prime = 1+y^2')
pause
print -dps2 wavelet_nl_ode_error.ps
