%
% `wiener-hopf.m'
%
% This program is copyrighted by SINC, LLC
% an belongs to SINC, LLC
%
% It solves the Wiener-Hopf problem, 
%
% f(x) - int_0^{infty} k(x-t) f(t) dt = g(x)
%
% with k(t) = exp(-|x-t|), 
%
%  g(t) = 2(1+t) exp(-t) + (1/3) exp(-2t)
%
% The exact solution is 
% 
% f(x) = 2 e^{-x} - e^{-2x} -- See Sec. 3.10.
%
clear all
M = 13;
N = 10;
m = M+N+1;
h = 3.5/sqrt(m);
z = Sincpoints4(M,N,h);
A = Int4_p(M,N,h);
B = Int4_m(M,N,h);
%
for j=1:m
    gg(j) = 2*(1+z(j))*exp(-z(j)) - 1/3*exp(-2*z(j));
    f_e(j) = 2*exp(-z(j)) - exp(-2*z(j));
end
%
g = gg.';
f_exact = f_e.';
%
C = A*inv(eye(m)+A);
D = B*inv(eye(m)+B);
%
E = eye(m) + C + D;
%
f_approx = E\g;
%
plot(z,f_exact,'o',z,f_approx)
%
pause
%
plot(z,f_approx-f_exact)
